unit LEXER;
{ lexical analyzer template (TP Lex V3.0), V1.0 3-2-91 AG		}
{ 24.3.98: repacked into an class to make code thread-safe.		}
{ Modified September 2000 by C.P.Osborne for Delphi 4/5			}
{	11/09/2000	CPO	Mods started.				}
{				Converted for new LexLib, YaccLib.	}
{	26/09/2000	CPO	New version for standalone Lexers.	}

interface

uses LexLib;

{ global definitions: 							}
  (* Lexical analyzer word count test
     Author C.P.Osborne
     Modified:
	25/09/2000	CPO	Created
  *)

var
  LineCount	: Integer;
  WordCount	: Integer;
  CharCount	: Integer;
  CommentCount	: Integer;

const COMMENT = 2;

const INITIAL = 0;

type
  YYSType = Integer;
  TLex = class( TCustomLexer )
    function yylex (var yylval: YYSType): Integer;
  end;

implementation

uses
  SysUtils;

function TLex.yylex(var yylval: YYSType): Integer;

procedure yyaction ( yyruleno : Integer );

{ local definitions:							}
begin
  { actions: 								}
  case yyruleno of
  1:
    		begin
		  Inc( CommentCount );
		  start( COMMENT );
		end;
  2:
      		begin
		  Inc(WordCount);
		  CharCount := CharCount + yyleng;
		end;
  3:
     		begin
		  Inc( CharCount );
		  Inc( LineCount );
		end;
  4:
 		begin
		  Inc( CharCount );
		end;
  5:
               	;
  6:
              	start( 0 );
  7:
          	;
  end;
end;	{ yyaction	}

{ DFA table: 								}

type YYTRec = record
                cc : set of Char;
                s  : Integer;
              end;

const

yynmarks   = 14;
yynmatches = 14;
yyntrans   = 21;
yynstates  = 14;

yyk : array [1..yynmarks] of Integer = (
  { 0: }
  { 1: }
  { 2: }
  { 3: }
  { 4: }
  2,
  4,
  { 5: }
  2,
  4,
  { 6: }
  3,
  { 7: }
  4,
  { 8: }
  5,
  7,
  { 9: }
  6,
  { 10: }
  7,
  { 11: }
  1,
  2,
  { 12: }
  2,
  { 13: }
  5
);

yym : array [1..yynmatches] of Integer = (
{ 0: }
{ 1: }
{ 2: }
{ 3: }
{ 4: }
  2,
  4,
{ 5: }
  2,
  4,
{ 6: }
  3,
{ 7: }
  4,
{ 8: }
  5,
  7,
{ 9: }
  6,
{ 10: }
  7,
{ 11: }
  1,
  2,
{ 12: }
  2,
{ 13: }
  5
);

yyt : array [1..yyntrans] of YYTrec = (
{ 0: }
  ( cc: [ #1..#8,#11..#31,'!'..'.','0'..#255 ]; s: 5),
  ( cc: [ #9,' ' ]; s: 7),
  ( cc: [ #10 ]; s: 6),
  ( cc: [ '/' ]; s: 4),
{ 1: }
  ( cc: [ #1..#8,#11..#31,'!'..'.','0'..#255 ]; s: 5),
  ( cc: [ #9,' ' ]; s: 7),
  ( cc: [ #10 ]; s: 6),
  ( cc: [ '/' ]; s: 4),
{ 2: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 8),
  ( cc: [ #9,' ' ]; s: 10),
  ( cc: [ #10 ]; s: 9),
{ 3: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 8),
  ( cc: [ #9,' ' ]; s: 10),
  ( cc: [ #10 ]; s: 9),
{ 4: }
  ( cc: [ #1..#8,#11..#31,'!'..'.','0'..#255 ]; s: 12),
  ( cc: [ '/' ]; s: 11),
{ 5: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 12),
{ 6: }
{ 7: }
{ 8: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 13),
{ 9: }
{ 10: }
{ 11: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 12),
{ 12: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 12),
{ 13: }
  ( cc: [ #1..#8,#11..#31,'!'..#255 ]; s: 13)
);

yykl : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 1,
{ 2: } 1,
{ 3: } 1,
{ 4: } 1,
{ 5: } 3,
{ 6: } 5,
{ 7: } 6,
{ 8: } 7,
{ 9: } 9,
{ 10: } 10,
{ 11: } 11,
{ 12: } 13,
{ 13: } 14
);

yykh : array [0..yynstates-1] of Integer = (
{ 0: } 0,
{ 1: } 0,
{ 2: } 0,
{ 3: } 0,
{ 4: } 2,
{ 5: } 4,
{ 6: } 5,
{ 7: } 6,
{ 8: } 8,
{ 9: } 9,
{ 10: } 10,
{ 11: } 12,
{ 12: } 13,
{ 13: } 14
);

yyml : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 1,
{ 2: } 1,
{ 3: } 1,
{ 4: } 1,
{ 5: } 3,
{ 6: } 5,
{ 7: } 6,
{ 8: } 7,
{ 9: } 9,
{ 10: } 10,
{ 11: } 11,
{ 12: } 13,
{ 13: } 14
);

yymh : array [0..yynstates-1] of Integer = (
{ 0: } 0,
{ 1: } 0,
{ 2: } 0,
{ 3: } 0,
{ 4: } 2,
{ 5: } 4,
{ 6: } 5,
{ 7: } 6,
{ 8: } 8,
{ 9: } 9,
{ 10: } 10,
{ 11: } 12,
{ 12: } 13,
{ 13: } 14
);

yytl : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 5,
{ 2: } 9,
{ 3: } 12,
{ 4: } 15,
{ 5: } 17,
{ 6: } 18,
{ 7: } 18,
{ 8: } 18,
{ 9: } 19,
{ 10: } 19,
{ 11: } 19,
{ 12: } 20,
{ 13: } 21
);

yyth : array [0..yynstates-1] of Integer = (
{ 0: } 4,
{ 1: } 8,
{ 2: } 11,
{ 3: } 14,
{ 4: } 16,
{ 5: } 17,
{ 6: } 17,
{ 7: } 17,
{ 8: } 18,
{ 9: } 18,
{ 10: } 18,
{ 11: } 19,
{ 12: } 20,
{ 13: } 21
);


var yyn : Integer;

label start, scan, action;

begin
start:
  { initialize:								}

  yynew;

scan:

  { Mark positions and matches: 					}

  for yyn := yykl[yystate] to     yykh[yystate] do yymark(yyk[yyn]);
  for yyn := yymh[yystate] downto yyml[yystate] do yymatch(yym[yyn]);

  if yytl[yystate]>yyth[yystate] then goto action;	{ dead state	}

  { Get next character:							}

  yyscan;

  { Determine action:							}

  yyn := yytl[yystate];
  while (yyn<=yyth[yystate]) and not (yyactchar in yyt[yyn].cc) do inc(yyn);
  if yyn>yyth[yystate] then goto action;
	{ No transition on yyactchar in this state.			}

  { Switch to new state:						}

  yystate := yyt[yyn].s;

  goto scan;

action:

  { Execute action: 							}

  if yyfind(yyrule) then
    begin
      yyaction(yyrule);
      if yyreject then goto action;
    end
  else if not yydefault and yywrap then
    begin
      yyclear;
      return(0);
    end;

  if not yydone then goto start;

  yylex := yyretval;
end;	{ yylex	}

end.

