unit TestForm;
{ Test noddy for Lex system.						}
{ This is just a simple word counter.					}
{ Author C.P.Osborne.							}
{ Modified:								}
{	26/09/2000	CPO	Created.				}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, LexFile;

type
  TfrmTest = class(TForm)
    SourceBox: TGroupBox;
    ResultBox: TGroupBox;
    ButtonBox: TGroupBox;
    GoButton: TBitBtn;
    LoadButton: TBitBtn;
    SourceMemo: TMemo;
    ResultMemo: TMemo;
    LoadDialog: TOpenDialog;
    ExitButton: TBitBtn;
    ClearButton: TBitBtn;
    procedure LoadButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ExitButtonClick(Sender: TObject);
    procedure GoButtonClick(Sender: TObject);
    procedure ClearButtonClick(Sender: TObject);
  private
    OPStr	: String;
    function OPHandler( mode : TFmode; C : Char ) : Char;
  end;

var
  frmTest: TfrmTest;

implementation

{$R *.DFM}
uses LexLib, Lexer;

var
  OurLexer	: TLex;		{ Our lexical analyser.			}

{ Load a file into the source memo.					}
procedure TfrmTest.LoadButtonClick(Sender: TObject);
var
  T	: TextFile;
  S	: String;
begin
  with LoadDialog do
  begin
    InitialDir := ExtractFilePath(Application.ExeName);
    if Execute then
    begin
      AssignFile( T, FileName );
      Reset( T );
      SourceMemo.Lines.Clear;
      while not Eof( T ) do
      begin
	Readln( T, S );
	SourceMemo.Lines.Add(S);
      end;
      CloseFile( T );
    end;
  end;
end;	{ LoadButtonClick	}

{ Set up system on creation.						}
procedure TfrmTest.FormCreate(Sender: TObject);
begin
  { Create the lexical analyser.					}
  OurLexer := TLex.Create;

  { We only want #13 as end of line.					}
  LexEOL := #13;
end;	{ FormCreate	}

{ User has had enough - and who can blame him eh?			}
procedure TfrmTest.ExitButtonClick(Sender: TObject);
begin
  Close;
end;	{ ExitButtonClick	}

{ Do the interpreting thing.						}
procedure TfrmTest.GoButtonClick(Sender: TObject);
var
  V	: YYStype;
begin
  { Clear result & variables.						}
  ResultMemo.Lines.Clear;
  LineCount := 1;
  WordCount := 0;
  CharCount := 0;
  CommentCount := 0;

  { Reset lex stuff.							}
  OurLexer.Reset;

  { Get input from source memo.						}
  OurLexer.yyinput.AssignString(SourceMemo.Lines.Text);

  { Assign output to our handler.					}
  OPstr := '';
  OurLexer.yyoutput.AssignMethod( OPHandler );

  { Finally scan the input.						}
  OurLexer.yylex(V);

  { Flush o/p strings.							}
  if OPStr <> '' then
  begin
    ResultMemo.Lines.Add( OPStr );
    OPStr := '';
  end;

  { Add results...							}
  if CharCount = 0 then LineCount := 0;
  ResultMemo.Lines.Add( Format( 'Words = %d', [WordCount] ) );
  ResultMemo.Lines.Add( Format( 'Lines = %d', [LineCount] ) );
  ResultMemo.Lines.Add( Format( 'Chars = %d', [CharCount] ) );
  ResultMemo.Lines.Add( Format( 'Cmnts = %d', [CommentCount] ) );

end;	{ GoButtonClick	}

{ Output data handler.							}
function TfrmTest.OPHandler(mode: TFmode; C: Char): Char;
begin
  Result := #0;

  case mode of
    tfEOF : Result := #1;		{ Never end of file		}
    tfGet : raise ELFException.Create('Not an input file');
    tfPut : begin
	      if C in [#10,#13] then
	      begin
		ResultMemo.Lines.Add( OPStr );
		OPStr := '';
	      end else OPStr := OPStr + C;
	    end;
  end;
end;	{ OPHandler	}

{ Clear the source pane.						}
procedure TfrmTest.ClearButtonClick(Sender: TObject);
begin
  SourceMemo.Lines.Clear;
end;	{ ClearButtonClick	}

end.
