unit PARSER;

{ Yacc parser template (TP Yacc V3.0), V1.2 6-17-91 AG			}
{ 24.3.98: repacked into an class to make code thread-safe.		}
{									}
{ Modified September 2000 by C.P.Osborne for Delphi 4/5			}
{	11/09/2000	CPO	Mods started.				}
{				Converted for LexLib, YaccLib.		}
{				No longer based on component.		}
{				Parser now derived from its library.	}
{				Debug now goes to yyerrorfile.		}

interface

{ global definitions: 							}


uses YaccLib, LexLib, ParseGlobals;

const TASSIGN = 257;
const RABS = 258;
const BIF = 259;
const BENDIF = 260;
const BIN = 261;
const NUMC = 262;
const STRC = 263;
const RID = 264;
const BID = 265;
const SID = 266;
const BTHEN = 267;
const BELSE = 268;
const LE = 269;
const GE = 270;
const NE = 271;
const BOR = 272;
const BAND = 273;
const UMINUS = 274;
const BNOT = 275;
const ILLEGAL = 276;

type YYSType = record
               yyString : String;
               case Integer of
                 1 : ( yyBoolean : Boolean );
                 2 : ( yyInteger : Integer );
                 3 : ( yyReal : Real );
               end;	{ YYSType	}

type
  TLex = class( TCustomLexer )
    function yylex (var yylval: YYSType): Integer;
  end;

  TYacc = class( TCustomParser )
    yylval: YYSType;
    constructor Create;
    destructor Destroy; override;
    function yyparse: Integer;
  end;

implementation

uses
  SysUtils;

constructor TYacc.Create;
begin
  inherited Create;
  ylex := TLex.Create;
end; { TYacc.Create }

destructor TYacc.Destroy;
begin
  ylex.Destroy;
  inherited Destroy;
end; { TYacc.Destroy }

function TYacc.yyparse : Integer;

var yystate, yysp, yyn : Integer;
    yys : array [1..yymaxdepth] of Integer;
    yyv : array [1..yymaxdepth] of YYSType;
    yyval : YYSType;

procedure yyaction ( yyruleno : Integer );
{ local definitions:							}
begin
{ actions: 								}
  case yyruleno of
   1 : begin
         yyval := yyv[yysp-0];
       end;
   2 : begin
         yyaccept; 		
       end;
   3 : begin
         Parse_If := yyv[yysp-1].yyBoolean and Parse_Run;	
       end;
   4 : begin
         Parse_If := Parse_Run and not Parse_If; 
       end;
   5 : begin
         Parse_If := Parse_Run; 
       end;
   6 : begin
         yyval := yyv[yysp-0];
       end;
   7 : begin
         yyval := yyv[yysp-2];
       end;
   8 : begin
         yyval := yyv[yysp-0];
       end;
   9 : begin
         yyval := yyv[yysp-0];
       end;
  10 : begin
         yyval := yyv[yysp-2];
       end;
  11 : begin
         yyval := yyv[yysp-4];
       end;
  12 : begin
         yyval := yyv[yysp-0];
       end;
  13 : begin
         yyval := yyv[yysp-2];
       end;
  14 : begin
         yyval := yyv[yysp-0];
       end;
  15 : begin
         yyval := yyv[yysp-0];
       end;
  16 : begin
       end;
  17 : begin
         
         				  if Parse_If then
         				  begin
         				    Parse_Reals[yyv[yysp-2].yyInteger].RVal  := yyv[yysp-0].yyReal;
         				    Parse_Reals[yyv[yysp-2].yyInteger].State := tReal;
         				  end;
         				
       end;
  18 : begin
         
         				  if Parse_If then
         				  begin
         				    Parse_Bools[yyv[yysp-2].yyInteger].BVal := yyv[yysp-0].yyBoolean;
         				    Parse_Bools[yyv[yysp-2].yyInteger].State := tBoolean;
         				  end;
         				
       end;
  19 : begin
         
         				  if Parse_If then
         				  begin
         				    Parse_Strings[yyv[yysp-2].yyInteger].SVal := yyv[yysp-0].yyString;
         				    Parse_Strings[yyv[yysp-2].yyInteger].State := tString;
         				  end;
         				
       end;
  20 : begin
         
         				  if Parse_If then
         				    ylex.yyoutput.Writeln(Format('%0.2f',[yyv[yysp-0].yyReal]));
         				
       end;
  21 : begin
         
         				  if Parse_If then
         				  begin
         				    if yyv[yysp-0].yyBoolean then ylex.yyoutput.Writeln('True')
         				    else ylex.yyoutput.Writeln('False' );
         				  end;
         				
       end;
  22 : begin
         
         				  if Parse_If then ylex.yyoutput.Writeln(yyv[yysp-0].yyString);
         				
       end;
  23 : begin
         yyval.yyReal := yyv[yysp-2].yyReal + yyv[yysp-0].yyReal; 	
       end;
  24 : begin
         yyval.yyReal := yyv[yysp-2].yyReal - yyv[yysp-0].yyReal; 	
       end;
  25 : begin
         yyval.yyReal := yyv[yysp-2].yyReal * yyv[yysp-0].yyReal; 	
       end;
  26 : begin
         
         				  if Parse_If then
         				  begin
         					if yyv[yysp-0].yyReal = 0 then
         					begin
         					  yyerror('Division by zero');
         					  Parse_Error := 1;
         					  yyabort;
         					end
         					else yyval.yyReal := yyv[yysp-2].yyReal / yyv[yysp-0].yyReal;
         				  end;
         				
       end;
  27 : begin
         yyval.yyReal := abs( yyv[yysp-1].yyReal );	
       end;
  28 : begin
         yyval.yyReal := yyv[yysp-1].yyReal; 		
       end;
  29 : begin
         yyval.yyReal := -yyv[yysp-0].yyReal;		
       end;
  30 : begin
         yyval.yyReal := yyv[yysp-0].yyReal; 		
       end;
  31 : begin
         
         				  if Parse_If then
         				  case Parse_Reals[yyv[yysp-0].yyInteger].State of
         				  tUndefined : begin
         						yyerror('Undefined variable');
         						Parse_Error := 2;
         						yyabort;
         					       end;
         				  tReal : yyval.yyReal := Parse_Reals[yyv[yysp-0].yyInteger].RVal;
         				  end;
         				
       end;
  32 : begin
         yyval.yyBoolean := yyv[yysp-2].yyReal < yyv[yysp-0].yyReal;	
       end;
  33 : begin
         yyval.yyBoolean := yyv[yysp-2].yyReal > yyv[yysp-0].yyReal;	
       end;
  34 : begin
         yyval.yyBoolean := yyv[yysp-2].yyReal = yyv[yysp-0].yyReal;	
       end;
  35 : begin
         yyval.yyBoolean := yyv[yysp-2].yyReal <> yyv[yysp-0].yyReal;	
       end;
  36 : begin
         yyval.yyBoolean := yyv[yysp-2].yyReal >= yyv[yysp-0].yyReal;	
       end;
  37 : begin
         yyval.yyBoolean := yyv[yysp-2].yyReal <= yyv[yysp-0].yyReal;	
       end;
  38 : begin
         yyval.yyBoolean := yyv[yysp-2].yyString = yyv[yysp-0].yyString;	
       end;
  39 : begin
         yyval.yyBoolean := yyv[yysp-2].yyString <> yyv[yysp-0].yyString;	
       end;
  40 : begin
         yyval.yyBoolean := yyv[yysp-2].yyString < yyv[yysp-0].yyString;	
       end;
  41 : begin
         yyval.yyBoolean := yyv[yysp-2].yyString > yyv[yysp-0].yyString;	
       end;
  42 : begin
         yyval.yyBoolean := yyv[yysp-2].yyString >= yyv[yysp-0].yyString;	
       end;
  43 : begin
         yyval.yyBoolean := yyv[yysp-2].yyString <= yyv[yysp-0].yyString;	
       end;
  44 : begin
         yyval.yyBoolean := yyv[yysp-2].yyBoolean = yyv[yysp-0].yyBoolean;	
       end;
  45 : begin
         yyval.yyBoolean := yyv[yysp-2].yyBoolean <> yyv[yysp-0].yyBoolean;	
       end;
  46 : begin
         yyval.yyBoolean := yyv[yysp-2].yyBoolean and yyv[yysp-0].yyBoolean;	
       end;
  47 : begin
         yyval.yyBoolean := yyv[yysp-2].yyBoolean or yyv[yysp-0].yyBoolean;	
       end;
  48 : begin
         yyval.yyBoolean := yyv[yysp-1].yyBoolean;		
       end;
  49 : begin
         yyval.yyBoolean := not yyv[yysp-0].yyBoolean;		
       end;
  50 : begin
         yyval.yyBoolean := pos(yyv[yysp-2].yyString,yyv[yysp-0].yyString) <> 0;
       end;
  51 : begin
         
         				  if Parse_If then
         				  case Parse_Bools[yyv[yysp-0].yyInteger].State of
         				  tUndefined : begin
         						yyerror('Undefined variable');
         						Parse_Error := 2;
         						yyabort;
         					       end;
         				  tBoolean : yyval.yyBoolean := Parse_Bools[yyv[yysp-0].yyInteger].BVal;
         				  end;
         				
       end;
  52 : begin
         yyval.yyString := yyv[yysp-0].yyString; 			
       end;
  53 : begin
         yyval.yyString := yyv[yysp-2].yyString + yyv[yysp-0].yyString;		
       end;
  54 : begin
         
         				  if (Integer(Trunc(yyv[yysp-1].yyReal)) < 1) or
         				    (Integer(Trunc(yyv[yysp-1].yyReal)) > Length(yyv[yysp-3].yyString)) then
         				  begin
         				    yyerror('Index error');
         				    Parse_Error := 5;
         				    yyabort;
         				  end else
         				  begin
         				    yyval.yyString := yyv[yysp-3].yyString[Integer(Trunc(yyv[yysp-1].yyReal))];
         				  end;
         				
       end;
  55 : begin
         
         				  if Parse_If then
         				  case Parse_Strings[yyv[yysp-0].yyInteger].State of
         				  tUndefined : begin
         						yyerror('Undefined variable');
         						Parse_Error := 2;
         						yyabort;
         					       end;
         				  tString : yyval.yyString := Parse_Strings[yyv[yysp-0].yyInteger].SVal;
         				  end;
         				
       end;
  end;
end;	{ yyaction }

{ parse table: 								}

type YYARec = record
                sym, act : Integer;
              end;
     YYRRec = record
                len, sym : Integer;
              end;

const

yynacts   = 628;
yyngotos  = 72;
yynstates = 107;
yynrules  = 55;

yya : array [1..yynacts] of YYARec = (
{ 0: }
  ( sym: 63; act: 7 ),
  ( sym: 259; act: 8 ),
  ( sym: 264; act: 9 ),
  ( sym: 265; act: 10 ),
  ( sym: 266; act: 11 ),
  ( sym: 0; act: -16 ),
  ( sym: 10; act: -16 ),
  ( sym: 35; act: -16 ),
  ( sym: 59; act: -16 ),
{ 1: }
{ 2: }
{ 3: }
{ 4: }
  ( sym: 63; act: 7 ),
  ( sym: 264; act: 9 ),
  ( sym: 265; act: 10 ),
  ( sym: 266; act: 11 ),
  ( sym: 10; act: -16 ),
  ( sym: 59; act: -16 ),
  ( sym: 260; act: -16 ),
  ( sym: 268; act: -16 ),
{ 5: }
  ( sym: 10; act: 15 ),
  ( sym: 59; act: 16 ),
  ( sym: 0; act: -1 ),
  ( sym: 35; act: -1 ),
{ 6: }
  ( sym: 0; act: 0 ),
  ( sym: 35; act: 17 ),
{ 7: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 8: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 9: }
  ( sym: 257; act: 33 ),
{ 10: }
  ( sym: 257; act: 34 ),
{ 11: }
  ( sym: 257; act: 35 ),
{ 12: }
  ( sym: 10; act: 15 ),
  ( sym: 59; act: 16 ),
  ( sym: 260; act: 39 ),
  ( sym: 268; act: 40 ),
{ 13: }
{ 14: }
  ( sym: 63; act: 7 ),
  ( sym: 259; act: 8 ),
  ( sym: 264; act: 9 ),
  ( sym: 265; act: 10 ),
  ( sym: 266; act: 11 ),
  ( sym: 0; act: -16 ),
  ( sym: 10; act: -16 ),
  ( sym: 35; act: -16 ),
  ( sym: 59; act: -16 ),
{ 15: }
{ 16: }
{ 17: }
{ 18: }
  ( sym: 43; act: 42 ),
  ( sym: 60; act: 43 ),
  ( sym: 61; act: 44 ),
  ( sym: 62; act: 45 ),
  ( sym: 91; act: 46 ),
  ( sym: 261; act: 47 ),
  ( sym: 269; act: 48 ),
  ( sym: 270; act: 49 ),
  ( sym: 271; act: 50 ),
  ( sym: 0; act: -22 ),
  ( sym: 10; act: -22 ),
  ( sym: 35; act: -22 ),
  ( sym: 59; act: -22 ),
  ( sym: 260; act: -22 ),
  ( sym: 268; act: -22 ),
{ 19: }
  ( sym: 61; act: 51 ),
  ( sym: 271; act: 52 ),
  ( sym: 272; act: 53 ),
  ( sym: 273; act: 54 ),
  ( sym: 0; act: -21 ),
  ( sym: 10; act: -21 ),
  ( sym: 35; act: -21 ),
  ( sym: 59; act: -21 ),
  ( sym: 260; act: -21 ),
  ( sym: 268; act: -21 ),
{ 20: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 60; act: 59 ),
  ( sym: 61; act: 60 ),
  ( sym: 62; act: 61 ),
  ( sym: 269; act: 62 ),
  ( sym: 270; act: 63 ),
  ( sym: 271; act: 64 ),
  ( sym: 0; act: -20 ),
  ( sym: 10; act: -20 ),
  ( sym: 35; act: -20 ),
  ( sym: 59; act: -20 ),
  ( sym: 260; act: -20 ),
  ( sym: 268; act: -20 ),
{ 21: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 22: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 23: }
  ( sym: 40; act: 69 ),
{ 24: }
{ 25: }
{ 26: }
{ 27: }
{ 28: }
{ 29: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 30: }
  ( sym: 43; act: 42 ),
  ( sym: 60; act: 43 ),
  ( sym: 61; act: 44 ),
  ( sym: 62; act: 45 ),
  ( sym: 91; act: 46 ),
  ( sym: 261; act: 47 ),
  ( sym: 269; act: 48 ),
  ( sym: 270; act: 49 ),
  ( sym: 271; act: 50 ),
{ 31: }
  ( sym: 61; act: 51 ),
  ( sym: 267; act: 71 ),
  ( sym: 271; act: 52 ),
  ( sym: 272; act: 53 ),
  ( sym: 273; act: 54 ),
{ 32: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 60; act: 59 ),
  ( sym: 61; act: 60 ),
  ( sym: 62; act: 61 ),
  ( sym: 269; act: 62 ),
  ( sym: 270; act: 63 ),
  ( sym: 271; act: 64 ),
{ 33: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 34: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 35: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 36: }
  ( sym: 63; act: 7 ),
  ( sym: 264; act: 9 ),
  ( sym: 265; act: 10 ),
  ( sym: 266; act: 11 ),
  ( sym: 10; act: -16 ),
  ( sym: 59; act: -16 ),
  ( sym: 260; act: -16 ),
  ( sym: 268; act: -16 ),
{ 37: }
{ 38: }
  ( sym: 63; act: 7 ),
  ( sym: 264; act: 9 ),
  ( sym: 265; act: 10 ),
  ( sym: 266; act: 11 ),
  ( sym: 10; act: -16 ),
  ( sym: 59; act: -16 ),
  ( sym: 260; act: -16 ),
{ 39: }
{ 40: }
{ 41: }
{ 42: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 43: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 44: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 45: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 46: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 47: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 48: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 49: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 50: }
  ( sym: 263; act: 25 ),
  ( sym: 266; act: 28 ),
{ 51: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 52: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 53: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 54: }
  ( sym: 40; act: 21 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 263; act: 25 ),
  ( sym: 264; act: 26 ),
  ( sym: 265; act: 27 ),
  ( sym: 266; act: 28 ),
  ( sym: 275; act: 29 ),
{ 55: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 56: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 57: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 58: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 59: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 60: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 61: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 62: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 63: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 64: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 65: }
  ( sym: 41; act: 100 ),
  ( sym: 61; act: 51 ),
  ( sym: 271; act: 52 ),
  ( sym: 272; act: 53 ),
  ( sym: 273; act: 54 ),
{ 66: }
  ( sym: 41; act: 101 ),
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 60; act: 59 ),
  ( sym: 61; act: 60 ),
  ( sym: 62; act: 61 ),
  ( sym: 269; act: 62 ),
  ( sym: 270; act: 63 ),
  ( sym: 271; act: 64 ),
{ 67: }
{ 68: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 69: }
  ( sym: 40; act: 68 ),
  ( sym: 45; act: 22 ),
  ( sym: 258; act: 23 ),
  ( sym: 262; act: 24 ),
  ( sym: 264; act: 26 ),
{ 70: }
{ 71: }
{ 72: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -17 ),
  ( sym: 10; act: -17 ),
  ( sym: 35; act: -17 ),
  ( sym: 59; act: -17 ),
  ( sym: 260; act: -17 ),
  ( sym: 268; act: -17 ),
{ 73: }
  ( sym: 61; act: 51 ),
  ( sym: 271; act: 52 ),
  ( sym: 272; act: 53 ),
  ( sym: 273; act: 54 ),
  ( sym: 0; act: -18 ),
  ( sym: 10; act: -18 ),
  ( sym: 35; act: -18 ),
  ( sym: 59; act: -18 ),
  ( sym: 260; act: -18 ),
  ( sym: 268; act: -18 ),
{ 74: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -19 ),
  ( sym: 10; act: -19 ),
  ( sym: 35; act: -19 ),
  ( sym: 59; act: -19 ),
  ( sym: 260; act: -19 ),
  ( sym: 268; act: -19 ),
{ 75: }
{ 76: }
  ( sym: 10; act: 15 ),
  ( sym: 59; act: 16 ),
  ( sym: 260; act: 39 ),
{ 77: }
{ 78: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -40 ),
  ( sym: 10; act: -40 ),
  ( sym: 35; act: -40 ),
  ( sym: 41; act: -40 ),
  ( sym: 59; act: -40 ),
  ( sym: 61; act: -40 ),
  ( sym: 260; act: -40 ),
  ( sym: 267; act: -40 ),
  ( sym: 268; act: -40 ),
  ( sym: 271; act: -40 ),
  ( sym: 272; act: -40 ),
  ( sym: 273; act: -40 ),
{ 79: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -38 ),
  ( sym: 10; act: -38 ),
  ( sym: 35; act: -38 ),
  ( sym: 41; act: -38 ),
  ( sym: 59; act: -38 ),
  ( sym: 61; act: -38 ),
  ( sym: 260; act: -38 ),
  ( sym: 267; act: -38 ),
  ( sym: 268; act: -38 ),
  ( sym: 271; act: -38 ),
  ( sym: 272; act: -38 ),
  ( sym: 273; act: -38 ),
{ 80: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -41 ),
  ( sym: 10; act: -41 ),
  ( sym: 35; act: -41 ),
  ( sym: 41; act: -41 ),
  ( sym: 59; act: -41 ),
  ( sym: 61; act: -41 ),
  ( sym: 260; act: -41 ),
  ( sym: 267; act: -41 ),
  ( sym: 268; act: -41 ),
  ( sym: 271; act: -41 ),
  ( sym: 272; act: -41 ),
  ( sym: 273; act: -41 ),
{ 81: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 93; act: 105 ),
{ 82: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -50 ),
  ( sym: 10; act: -50 ),
  ( sym: 35; act: -50 ),
  ( sym: 41; act: -50 ),
  ( sym: 59; act: -50 ),
  ( sym: 61; act: -50 ),
  ( sym: 260; act: -50 ),
  ( sym: 267; act: -50 ),
  ( sym: 268; act: -50 ),
  ( sym: 271; act: -50 ),
  ( sym: 272; act: -50 ),
  ( sym: 273; act: -50 ),
{ 83: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -43 ),
  ( sym: 10; act: -43 ),
  ( sym: 35; act: -43 ),
  ( sym: 41; act: -43 ),
  ( sym: 59; act: -43 ),
  ( sym: 61; act: -43 ),
  ( sym: 260; act: -43 ),
  ( sym: 267; act: -43 ),
  ( sym: 268; act: -43 ),
  ( sym: 271; act: -43 ),
  ( sym: 272; act: -43 ),
  ( sym: 273; act: -43 ),
{ 84: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -42 ),
  ( sym: 10; act: -42 ),
  ( sym: 35; act: -42 ),
  ( sym: 41; act: -42 ),
  ( sym: 59; act: -42 ),
  ( sym: 61; act: -42 ),
  ( sym: 260; act: -42 ),
  ( sym: 267; act: -42 ),
  ( sym: 268; act: -42 ),
  ( sym: 271; act: -42 ),
  ( sym: 272; act: -42 ),
  ( sym: 273; act: -42 ),
{ 85: }
  ( sym: 43; act: 42 ),
  ( sym: 91; act: 46 ),
  ( sym: 0; act: -39 ),
  ( sym: 10; act: -39 ),
  ( sym: 35; act: -39 ),
  ( sym: 41; act: -39 ),
  ( sym: 59; act: -39 ),
  ( sym: 61; act: -39 ),
  ( sym: 260; act: -39 ),
  ( sym: 267; act: -39 ),
  ( sym: 268; act: -39 ),
  ( sym: 271; act: -39 ),
  ( sym: 272; act: -39 ),
  ( sym: 273; act: -39 ),
{ 86: }
  ( sym: 272; act: 53 ),
  ( sym: 273; act: 54 ),
  ( sym: 0; act: -44 ),
  ( sym: 10; act: -44 ),
  ( sym: 35; act: -44 ),
  ( sym: 41; act: -44 ),
  ( sym: 59; act: -44 ),
  ( sym: 61; act: -44 ),
  ( sym: 260; act: -44 ),
  ( sym: 267; act: -44 ),
  ( sym: 268; act: -44 ),
  ( sym: 271; act: -44 ),
{ 87: }
  ( sym: 272; act: 53 ),
  ( sym: 273; act: 54 ),
  ( sym: 0; act: -45 ),
  ( sym: 10; act: -45 ),
  ( sym: 35; act: -45 ),
  ( sym: 41; act: -45 ),
  ( sym: 59; act: -45 ),
  ( sym: 61; act: -45 ),
  ( sym: 260; act: -45 ),
  ( sym: 267; act: -45 ),
  ( sym: 268; act: -45 ),
  ( sym: 271; act: -45 ),
{ 88: }
  ( sym: 273; act: 54 ),
  ( sym: 0; act: -47 ),
  ( sym: 10; act: -47 ),
  ( sym: 35; act: -47 ),
  ( sym: 41; act: -47 ),
  ( sym: 59; act: -47 ),
  ( sym: 61; act: -47 ),
  ( sym: 260; act: -47 ),
  ( sym: 267; act: -47 ),
  ( sym: 268; act: -47 ),
  ( sym: 271; act: -47 ),
  ( sym: 272; act: -47 ),
{ 89: }
{ 90: }
{ 91: }
  ( sym: 42; act: 55 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -23 ),
  ( sym: 10; act: -23 ),
  ( sym: 35; act: -23 ),
  ( sym: 41; act: -23 ),
  ( sym: 43; act: -23 ),
  ( sym: 45; act: -23 ),
  ( sym: 59; act: -23 ),
  ( sym: 60; act: -23 ),
  ( sym: 61; act: -23 ),
  ( sym: 62; act: -23 ),
  ( sym: 93; act: -23 ),
  ( sym: 260; act: -23 ),
  ( sym: 267; act: -23 ),
  ( sym: 268; act: -23 ),
  ( sym: 269; act: -23 ),
  ( sym: 270; act: -23 ),
  ( sym: 271; act: -23 ),
  ( sym: 272; act: -23 ),
  ( sym: 273; act: -23 ),
{ 92: }
  ( sym: 42; act: 55 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -24 ),
  ( sym: 10; act: -24 ),
  ( sym: 35; act: -24 ),
  ( sym: 41; act: -24 ),
  ( sym: 43; act: -24 ),
  ( sym: 45; act: -24 ),
  ( sym: 59; act: -24 ),
  ( sym: 60; act: -24 ),
  ( sym: 61; act: -24 ),
  ( sym: 62; act: -24 ),
  ( sym: 93; act: -24 ),
  ( sym: 260; act: -24 ),
  ( sym: 267; act: -24 ),
  ( sym: 268; act: -24 ),
  ( sym: 269; act: -24 ),
  ( sym: 270; act: -24 ),
  ( sym: 271; act: -24 ),
  ( sym: 272; act: -24 ),
  ( sym: 273; act: -24 ),
{ 93: }
{ 94: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -32 ),
  ( sym: 10; act: -32 ),
  ( sym: 35; act: -32 ),
  ( sym: 41; act: -32 ),
  ( sym: 59; act: -32 ),
  ( sym: 61; act: -32 ),
  ( sym: 260; act: -32 ),
  ( sym: 267; act: -32 ),
  ( sym: 268; act: -32 ),
  ( sym: 271; act: -32 ),
  ( sym: 272; act: -32 ),
  ( sym: 273; act: -32 ),
{ 95: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -34 ),
  ( sym: 10; act: -34 ),
  ( sym: 35; act: -34 ),
  ( sym: 41; act: -34 ),
  ( sym: 59; act: -34 ),
  ( sym: 61; act: -34 ),
  ( sym: 260; act: -34 ),
  ( sym: 267; act: -34 ),
  ( sym: 268; act: -34 ),
  ( sym: 271; act: -34 ),
  ( sym: 272; act: -34 ),
  ( sym: 273; act: -34 ),
{ 96: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -33 ),
  ( sym: 10; act: -33 ),
  ( sym: 35; act: -33 ),
  ( sym: 41; act: -33 ),
  ( sym: 59; act: -33 ),
  ( sym: 61; act: -33 ),
  ( sym: 260; act: -33 ),
  ( sym: 267; act: -33 ),
  ( sym: 268; act: -33 ),
  ( sym: 271; act: -33 ),
  ( sym: 272; act: -33 ),
  ( sym: 273; act: -33 ),
{ 97: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -37 ),
  ( sym: 10; act: -37 ),
  ( sym: 35; act: -37 ),
  ( sym: 41; act: -37 ),
  ( sym: 59; act: -37 ),
  ( sym: 61; act: -37 ),
  ( sym: 260; act: -37 ),
  ( sym: 267; act: -37 ),
  ( sym: 268; act: -37 ),
  ( sym: 271; act: -37 ),
  ( sym: 272; act: -37 ),
  ( sym: 273; act: -37 ),
{ 98: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -36 ),
  ( sym: 10; act: -36 ),
  ( sym: 35; act: -36 ),
  ( sym: 41; act: -36 ),
  ( sym: 59; act: -36 ),
  ( sym: 61; act: -36 ),
  ( sym: 260; act: -36 ),
  ( sym: 267; act: -36 ),
  ( sym: 268; act: -36 ),
  ( sym: 271; act: -36 ),
  ( sym: 272; act: -36 ),
  ( sym: 273; act: -36 ),
{ 99: }
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
  ( sym: 0; act: -35 ),
  ( sym: 10; act: -35 ),
  ( sym: 35; act: -35 ),
  ( sym: 41; act: -35 ),
  ( sym: 59; act: -35 ),
  ( sym: 61; act: -35 ),
  ( sym: 260; act: -35 ),
  ( sym: 267; act: -35 ),
  ( sym: 268; act: -35 ),
  ( sym: 271; act: -35 ),
  ( sym: 272; act: -35 ),
  ( sym: 273; act: -35 ),
{ 100: }
{ 101: }
{ 102: }
  ( sym: 41; act: 101 ),
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 ),
{ 103: }
  ( sym: 41; act: 106 ),
  ( sym: 42; act: 55 ),
  ( sym: 43; act: 56 ),
  ( sym: 45; act: 57 ),
  ( sym: 47; act: 58 )
{ 104: }
{ 105: }
{ 106: }
);

yyg : array [1..yyngotos] of YYARec = (
{ 0: }
  ( sym: -13; act: 1 ),
  ( sym: -12; act: 2 ),
  ( sym: -10; act: 3 ),
  ( sym: -7; act: 4 ),
  ( sym: -6; act: 5 ),
  ( sym: -5; act: 6 ),
{ 1: }
{ 2: }
{ 3: }
{ 4: }
  ( sym: -14; act: 12 ),
  ( sym: -12; act: 13 ),
{ 5: }
  ( sym: -11; act: 14 ),
{ 6: }
{ 7: }
  ( sym: -4; act: 18 ),
  ( sym: -3; act: 19 ),
  ( sym: -2; act: 20 ),
{ 8: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 31 ),
  ( sym: -2; act: 32 ),
{ 9: }
{ 10: }
{ 11: }
{ 12: }
  ( sym: -11; act: 36 ),
  ( sym: -9; act: 37 ),
  ( sym: -8; act: 38 ),
{ 13: }
{ 14: }
  ( sym: -13; act: 1 ),
  ( sym: -12; act: 2 ),
  ( sym: -10; act: 41 ),
  ( sym: -7; act: 4 ),
{ 15: }
{ 16: }
{ 17: }
{ 18: }
{ 19: }
{ 20: }
{ 21: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 65 ),
  ( sym: -2; act: 66 ),
{ 22: }
  ( sym: -2; act: 67 ),
{ 23: }
{ 24: }
{ 25: }
{ 26: }
{ 27: }
{ 28: }
{ 29: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 70 ),
  ( sym: -2; act: 32 ),
{ 30: }
{ 31: }
{ 32: }
{ 33: }
  ( sym: -2; act: 72 ),
{ 34: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 73 ),
  ( sym: -2; act: 32 ),
{ 35: }
  ( sym: -4; act: 74 ),
{ 36: }
  ( sym: -12; act: 75 ),
{ 37: }
{ 38: }
  ( sym: -14; act: 76 ),
  ( sym: -12; act: 13 ),
{ 39: }
{ 40: }
{ 41: }
{ 42: }
  ( sym: -4; act: 77 ),
{ 43: }
  ( sym: -4; act: 78 ),
{ 44: }
  ( sym: -4; act: 79 ),
{ 45: }
  ( sym: -4; act: 80 ),
{ 46: }
  ( sym: -2; act: 81 ),
{ 47: }
  ( sym: -4; act: 82 ),
{ 48: }
  ( sym: -4; act: 83 ),
{ 49: }
  ( sym: -4; act: 84 ),
{ 50: }
  ( sym: -4; act: 85 ),
{ 51: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 86 ),
  ( sym: -2; act: 32 ),
{ 52: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 87 ),
  ( sym: -2; act: 32 ),
{ 53: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 88 ),
  ( sym: -2; act: 32 ),
{ 54: }
  ( sym: -4; act: 30 ),
  ( sym: -3; act: 89 ),
  ( sym: -2; act: 32 ),
{ 55: }
  ( sym: -2; act: 90 ),
{ 56: }
  ( sym: -2; act: 91 ),
{ 57: }
  ( sym: -2; act: 92 ),
{ 58: }
  ( sym: -2; act: 93 ),
{ 59: }
  ( sym: -2; act: 94 ),
{ 60: }
  ( sym: -2; act: 95 ),
{ 61: }
  ( sym: -2; act: 96 ),
{ 62: }
  ( sym: -2; act: 97 ),
{ 63: }
  ( sym: -2; act: 98 ),
{ 64: }
  ( sym: -2; act: 99 ),
{ 65: }
{ 66: }
{ 67: }
{ 68: }
  ( sym: -2; act: 102 ),
{ 69: }
  ( sym: -2; act: 103 ),
{ 70: }
{ 71: }
{ 72: }
{ 73: }
{ 74: }
{ 75: }
{ 76: }
  ( sym: -11; act: 36 ),
  ( sym: -9; act: 104 )
{ 77: }
{ 78: }
{ 79: }
{ 80: }
{ 81: }
{ 82: }
{ 83: }
{ 84: }
{ 85: }
{ 86: }
{ 87: }
{ 88: }
{ 89: }
{ 90: }
{ 91: }
{ 92: }
{ 93: }
{ 94: }
{ 95: }
{ 96: }
{ 97: }
{ 98: }
{ 99: }
{ 100: }
{ 101: }
{ 102: }
{ 103: }
{ 104: }
{ 105: }
{ 106: }
);

yyd : array [0..yynstates-1] of Integer = (
{ 0: } 0,
{ 1: } -9,
{ 2: } -8,
{ 3: } -6,
{ 4: } 0,
{ 5: } 0,
{ 6: } 0,
{ 7: } 0,
{ 8: } 0,
{ 9: } 0,
{ 10: } 0,
{ 11: } 0,
{ 12: } 0,
{ 13: } -12,
{ 14: } 0,
{ 15: } -15,
{ 16: } -14,
{ 17: } -2,
{ 18: } 0,
{ 19: } 0,
{ 20: } 0,
{ 21: } 0,
{ 22: } 0,
{ 23: } 0,
{ 24: } -30,
{ 25: } -52,
{ 26: } -31,
{ 27: } -51,
{ 28: } -55,
{ 29: } 0,
{ 30: } 0,
{ 31: } 0,
{ 32: } 0,
{ 33: } 0,
{ 34: } 0,
{ 35: } 0,
{ 36: } 0,
{ 37: } -10,
{ 38: } 0,
{ 39: } -5,
{ 40: } -4,
{ 41: } -7,
{ 42: } 0,
{ 43: } 0,
{ 44: } 0,
{ 45: } 0,
{ 46: } 0,
{ 47: } 0,
{ 48: } 0,
{ 49: } 0,
{ 50: } 0,
{ 51: } 0,
{ 52: } 0,
{ 53: } 0,
{ 54: } 0,
{ 55: } 0,
{ 56: } 0,
{ 57: } 0,
{ 58: } 0,
{ 59: } 0,
{ 60: } 0,
{ 61: } 0,
{ 62: } 0,
{ 63: } 0,
{ 64: } 0,
{ 65: } 0,
{ 66: } 0,
{ 67: } -29,
{ 68: } 0,
{ 69: } 0,
{ 70: } -49,
{ 71: } -3,
{ 72: } 0,
{ 73: } 0,
{ 74: } 0,
{ 75: } -13,
{ 76: } 0,
{ 77: } -53,
{ 78: } 0,
{ 79: } 0,
{ 80: } 0,
{ 81: } 0,
{ 82: } 0,
{ 83: } 0,
{ 84: } 0,
{ 85: } 0,
{ 86: } 0,
{ 87: } 0,
{ 88: } 0,
{ 89: } -46,
{ 90: } -25,
{ 91: } 0,
{ 92: } 0,
{ 93: } -26,
{ 94: } 0,
{ 95: } 0,
{ 96: } 0,
{ 97: } 0,
{ 98: } 0,
{ 99: } 0,
{ 100: } -48,
{ 101: } -28,
{ 102: } 0,
{ 103: } 0,
{ 104: } -11,
{ 105: } -54,
{ 106: } -27
);

yyal : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 10,
{ 2: } 10,
{ 3: } 10,
{ 4: } 10,
{ 5: } 18,
{ 6: } 22,
{ 7: } 24,
{ 8: } 33,
{ 9: } 42,
{ 10: } 43,
{ 11: } 44,
{ 12: } 45,
{ 13: } 49,
{ 14: } 49,
{ 15: } 58,
{ 16: } 58,
{ 17: } 58,
{ 18: } 58,
{ 19: } 73,
{ 20: } 83,
{ 21: } 99,
{ 22: } 108,
{ 23: } 113,
{ 24: } 114,
{ 25: } 114,
{ 26: } 114,
{ 27: } 114,
{ 28: } 114,
{ 29: } 114,
{ 30: } 123,
{ 31: } 132,
{ 32: } 137,
{ 33: } 147,
{ 34: } 152,
{ 35: } 161,
{ 36: } 163,
{ 37: } 171,
{ 38: } 171,
{ 39: } 178,
{ 40: } 178,
{ 41: } 178,
{ 42: } 178,
{ 43: } 180,
{ 44: } 182,
{ 45: } 184,
{ 46: } 186,
{ 47: } 191,
{ 48: } 193,
{ 49: } 195,
{ 50: } 197,
{ 51: } 199,
{ 52: } 208,
{ 53: } 217,
{ 54: } 226,
{ 55: } 235,
{ 56: } 240,
{ 57: } 245,
{ 58: } 250,
{ 59: } 255,
{ 60: } 260,
{ 61: } 265,
{ 62: } 270,
{ 63: } 275,
{ 64: } 280,
{ 65: } 285,
{ 66: } 290,
{ 67: } 301,
{ 68: } 301,
{ 69: } 306,
{ 70: } 311,
{ 71: } 311,
{ 72: } 311,
{ 73: } 321,
{ 74: } 331,
{ 75: } 339,
{ 76: } 339,
{ 77: } 342,
{ 78: } 342,
{ 79: } 356,
{ 80: } 370,
{ 81: } 384,
{ 82: } 389,
{ 83: } 403,
{ 84: } 417,
{ 85: } 431,
{ 86: } 445,
{ 87: } 457,
{ 88: } 469,
{ 89: } 481,
{ 90: } 481,
{ 91: } 481,
{ 92: } 502,
{ 93: } 523,
{ 94: } 523,
{ 95: } 539,
{ 96: } 555,
{ 97: } 571,
{ 98: } 587,
{ 99: } 603,
{ 100: } 619,
{ 101: } 619,
{ 102: } 619,
{ 103: } 624,
{ 104: } 629,
{ 105: } 629,
{ 106: } 629
);

yyah : array [0..yynstates-1] of Integer = (
{ 0: } 9,
{ 1: } 9,
{ 2: } 9,
{ 3: } 9,
{ 4: } 17,
{ 5: } 21,
{ 6: } 23,
{ 7: } 32,
{ 8: } 41,
{ 9: } 42,
{ 10: } 43,
{ 11: } 44,
{ 12: } 48,
{ 13: } 48,
{ 14: } 57,
{ 15: } 57,
{ 16: } 57,
{ 17: } 57,
{ 18: } 72,
{ 19: } 82,
{ 20: } 98,
{ 21: } 107,
{ 22: } 112,
{ 23: } 113,
{ 24: } 113,
{ 25: } 113,
{ 26: } 113,
{ 27: } 113,
{ 28: } 113,
{ 29: } 122,
{ 30: } 131,
{ 31: } 136,
{ 32: } 146,
{ 33: } 151,
{ 34: } 160,
{ 35: } 162,
{ 36: } 170,
{ 37: } 170,
{ 38: } 177,
{ 39: } 177,
{ 40: } 177,
{ 41: } 177,
{ 42: } 179,
{ 43: } 181,
{ 44: } 183,
{ 45: } 185,
{ 46: } 190,
{ 47: } 192,
{ 48: } 194,
{ 49: } 196,
{ 50: } 198,
{ 51: } 207,
{ 52: } 216,
{ 53: } 225,
{ 54: } 234,
{ 55: } 239,
{ 56: } 244,
{ 57: } 249,
{ 58: } 254,
{ 59: } 259,
{ 60: } 264,
{ 61: } 269,
{ 62: } 274,
{ 63: } 279,
{ 64: } 284,
{ 65: } 289,
{ 66: } 300,
{ 67: } 300,
{ 68: } 305,
{ 69: } 310,
{ 70: } 310,
{ 71: } 310,
{ 72: } 320,
{ 73: } 330,
{ 74: } 338,
{ 75: } 338,
{ 76: } 341,
{ 77: } 341,
{ 78: } 355,
{ 79: } 369,
{ 80: } 383,
{ 81: } 388,
{ 82: } 402,
{ 83: } 416,
{ 84: } 430,
{ 85: } 444,
{ 86: } 456,
{ 87: } 468,
{ 88: } 480,
{ 89: } 480,
{ 90: } 480,
{ 91: } 501,
{ 92: } 522,
{ 93: } 522,
{ 94: } 538,
{ 95: } 554,
{ 96: } 570,
{ 97: } 586,
{ 98: } 602,
{ 99: } 618,
{ 100: } 618,
{ 101: } 618,
{ 102: } 623,
{ 103: } 628,
{ 104: } 628,
{ 105: } 628,
{ 106: } 628
);

yygl : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 7,
{ 2: } 7,
{ 3: } 7,
{ 4: } 7,
{ 5: } 9,
{ 6: } 10,
{ 7: } 10,
{ 8: } 13,
{ 9: } 16,
{ 10: } 16,
{ 11: } 16,
{ 12: } 16,
{ 13: } 19,
{ 14: } 19,
{ 15: } 23,
{ 16: } 23,
{ 17: } 23,
{ 18: } 23,
{ 19: } 23,
{ 20: } 23,
{ 21: } 23,
{ 22: } 26,
{ 23: } 27,
{ 24: } 27,
{ 25: } 27,
{ 26: } 27,
{ 27: } 27,
{ 28: } 27,
{ 29: } 27,
{ 30: } 30,
{ 31: } 30,
{ 32: } 30,
{ 33: } 30,
{ 34: } 31,
{ 35: } 34,
{ 36: } 35,
{ 37: } 36,
{ 38: } 36,
{ 39: } 38,
{ 40: } 38,
{ 41: } 38,
{ 42: } 38,
{ 43: } 39,
{ 44: } 40,
{ 45: } 41,
{ 46: } 42,
{ 47: } 43,
{ 48: } 44,
{ 49: } 45,
{ 50: } 46,
{ 51: } 47,
{ 52: } 50,
{ 53: } 53,
{ 54: } 56,
{ 55: } 59,
{ 56: } 60,
{ 57: } 61,
{ 58: } 62,
{ 59: } 63,
{ 60: } 64,
{ 61: } 65,
{ 62: } 66,
{ 63: } 67,
{ 64: } 68,
{ 65: } 69,
{ 66: } 69,
{ 67: } 69,
{ 68: } 69,
{ 69: } 70,
{ 70: } 71,
{ 71: } 71,
{ 72: } 71,
{ 73: } 71,
{ 74: } 71,
{ 75: } 71,
{ 76: } 71,
{ 77: } 73,
{ 78: } 73,
{ 79: } 73,
{ 80: } 73,
{ 81: } 73,
{ 82: } 73,
{ 83: } 73,
{ 84: } 73,
{ 85: } 73,
{ 86: } 73,
{ 87: } 73,
{ 88: } 73,
{ 89: } 73,
{ 90: } 73,
{ 91: } 73,
{ 92: } 73,
{ 93: } 73,
{ 94: } 73,
{ 95: } 73,
{ 96: } 73,
{ 97: } 73,
{ 98: } 73,
{ 99: } 73,
{ 100: } 73,
{ 101: } 73,
{ 102: } 73,
{ 103: } 73,
{ 104: } 73,
{ 105: } 73,
{ 106: } 73
);

yygh : array [0..yynstates-1] of Integer = (
{ 0: } 6,
{ 1: } 6,
{ 2: } 6,
{ 3: } 6,
{ 4: } 8,
{ 5: } 9,
{ 6: } 9,
{ 7: } 12,
{ 8: } 15,
{ 9: } 15,
{ 10: } 15,
{ 11: } 15,
{ 12: } 18,
{ 13: } 18,
{ 14: } 22,
{ 15: } 22,
{ 16: } 22,
{ 17: } 22,
{ 18: } 22,
{ 19: } 22,
{ 20: } 22,
{ 21: } 25,
{ 22: } 26,
{ 23: } 26,
{ 24: } 26,
{ 25: } 26,
{ 26: } 26,
{ 27: } 26,
{ 28: } 26,
{ 29: } 29,
{ 30: } 29,
{ 31: } 29,
{ 32: } 29,
{ 33: } 30,
{ 34: } 33,
{ 35: } 34,
{ 36: } 35,
{ 37: } 35,
{ 38: } 37,
{ 39: } 37,
{ 40: } 37,
{ 41: } 37,
{ 42: } 38,
{ 43: } 39,
{ 44: } 40,
{ 45: } 41,
{ 46: } 42,
{ 47: } 43,
{ 48: } 44,
{ 49: } 45,
{ 50: } 46,
{ 51: } 49,
{ 52: } 52,
{ 53: } 55,
{ 54: } 58,
{ 55: } 59,
{ 56: } 60,
{ 57: } 61,
{ 58: } 62,
{ 59: } 63,
{ 60: } 64,
{ 61: } 65,
{ 62: } 66,
{ 63: } 67,
{ 64: } 68,
{ 65: } 68,
{ 66: } 68,
{ 67: } 68,
{ 68: } 69,
{ 69: } 70,
{ 70: } 70,
{ 71: } 70,
{ 72: } 70,
{ 73: } 70,
{ 74: } 70,
{ 75: } 70,
{ 76: } 72,
{ 77: } 72,
{ 78: } 72,
{ 79: } 72,
{ 80: } 72,
{ 81: } 72,
{ 82: } 72,
{ 83: } 72,
{ 84: } 72,
{ 85: } 72,
{ 86: } 72,
{ 87: } 72,
{ 88: } 72,
{ 89: } 72,
{ 90: } 72,
{ 91: } 72,
{ 92: } 72,
{ 93: } 72,
{ 94: } 72,
{ 95: } 72,
{ 96: } 72,
{ 97: } 72,
{ 98: } 72,
{ 99: } 72,
{ 100: } 72,
{ 101: } 72,
{ 102: } 72,
{ 103: } 72,
{ 104: } 72,
{ 105: } 72,
{ 106: } 72
);

yyr : array [1..yynrules] of YYRRec = (
{ 1: } ( len: 1; sym: -5 ),
{ 2: } ( len: 2; sym: -5 ),
{ 3: } ( len: 3; sym: -7 ),
{ 4: } ( len: 1; sym: -8 ),
{ 5: } ( len: 1; sym: -9 ),
{ 6: } ( len: 1; sym: -6 ),
{ 7: } ( len: 3; sym: -6 ),
{ 8: } ( len: 1; sym: -10 ),
{ 9: } ( len: 1; sym: -10 ),
{ 10: } ( len: 3; sym: -13 ),
{ 11: } ( len: 5; sym: -13 ),
{ 12: } ( len: 1; sym: -14 ),
{ 13: } ( len: 3; sym: -14 ),
{ 14: } ( len: 1; sym: -11 ),
{ 15: } ( len: 1; sym: -11 ),
{ 16: } ( len: 0; sym: -12 ),
{ 17: } ( len: 3; sym: -12 ),
{ 18: } ( len: 3; sym: -12 ),
{ 19: } ( len: 3; sym: -12 ),
{ 20: } ( len: 2; sym: -12 ),
{ 21: } ( len: 2; sym: -12 ),
{ 22: } ( len: 2; sym: -12 ),
{ 23: } ( len: 3; sym: -2 ),
{ 24: } ( len: 3; sym: -2 ),
{ 25: } ( len: 3; sym: -2 ),
{ 26: } ( len: 3; sym: -2 ),
{ 27: } ( len: 4; sym: -2 ),
{ 28: } ( len: 3; sym: -2 ),
{ 29: } ( len: 2; sym: -2 ),
{ 30: } ( len: 1; sym: -2 ),
{ 31: } ( len: 1; sym: -2 ),
{ 32: } ( len: 3; sym: -3 ),
{ 33: } ( len: 3; sym: -3 ),
{ 34: } ( len: 3; sym: -3 ),
{ 35: } ( len: 3; sym: -3 ),
{ 36: } ( len: 3; sym: -3 ),
{ 37: } ( len: 3; sym: -3 ),
{ 38: } ( len: 3; sym: -3 ),
{ 39: } ( len: 3; sym: -3 ),
{ 40: } ( len: 3; sym: -3 ),
{ 41: } ( len: 3; sym: -3 ),
{ 42: } ( len: 3; sym: -3 ),
{ 43: } ( len: 3; sym: -3 ),
{ 44: } ( len: 3; sym: -3 ),
{ 45: } ( len: 3; sym: -3 ),
{ 46: } ( len: 3; sym: -3 ),
{ 47: } ( len: 3; sym: -3 ),
{ 48: } ( len: 3; sym: -3 ),
{ 49: } ( len: 2; sym: -3 ),
{ 50: } ( len: 3; sym: -3 ),
{ 51: } ( len: 1; sym: -3 ),
{ 52: } ( len: 1; sym: -4 ),
{ 53: } ( len: 3; sym: -4 ),
{ 54: } ( len: 4; sym: -4 ),
{ 55: } ( len: 1; sym: -4 )
);


const _error = 256;	{ error token					}

function yyact(state, sym : Integer; var act : Integer) : Boolean;
{ search action table 							}
var
  k	: Integer;
begin
  k := yyal[state];
  while (k<=yyah[state]) and (yya[k].sym<>sym) do inc(k);
  if k>yyah[state] then
    yyact := false
  else
  begin
    act := yya[k].act;
    yyact := true;
  end;
end;	{ yyact	}

function yygoto(state, sym : Integer; var nstate : Integer) : Boolean;
{ search goto table							}
var
  k	: Integer;
begin
  k := yygl[state];
  while (k<=yygh[state]) and (yyg[k].sym<>sym) do inc(k);
  if k>yygh[state] then
    yygoto := false
  else
  begin
    nstate := yyg[k].act;
    yygoto := true;
  end;
end;	{ yygoto	}

label parse, next, error, errlab, shift, reduce, accept, abort;

begin	{ yyparse							}
{ initialize: 								}

  yystate := 0; yychar := -1; yynerrs := 0; yyerrflag := 0; yysp := 0;

parse:

  { push state and value: 						}

  inc(yysp);
  if yysp>yymaxdepth then
    begin
      yyerror('yyparse stack overflow');
      goto abort;
    end;
  yys[yysp] := yystate; yyv[yysp] := yyval;

next:

  if (yyd[yystate]=0) and (yychar=-1) then
  { get next symbol							}
    begin
      yychar := TLex(ylex).yylex(yylval); if yychar<0 then yychar := 0;
      if yydebuglex then EWriteln( ylex.yytext );
    end;

  if yydebug then EWriteln(
	Format( 'state : %d, char : %d', [yystate, yychar] ) );

  { determine parse action: 						}

  yyn := yyd[yystate];
  if yyn<>0 then goto reduce; 		{ simple state 			}

  { no default action; search parse table 				}

  if not yyact(yystate, yychar, yyn) then goto error
  else if yyn>0 then                      goto shift
  else if yyn<0 then                      goto reduce
  else                                    goto accept;

error:

  { error; start error recovery: 					}

  if yyerrflag=0 then yyerror('syntax error');

errlab:

  if yyerrflag=0 then inc(yynerrs);	{ new error 			}

  if yyerrflag<=2 then                  { incomplete recovery; retry	}
    begin
      yyerrflag := 3;
      { uncover a state with shift action on error token 		}
      while (yysp>0) and not ( yyact(yys[yysp], _error, yyn) and
			       (yyn>0) ) do
	begin
	  if yydebug then
	    if yysp>1 then
	      EWriteln(
		Format( 'error recovery pops state : %d, uncovers : %d',
			[ yys[yysp], yys[yysp-1 ] ]) )
	    else
	      EWriteln('error recovery fails ... abort');
	  dec(yysp);
	end;
      if yysp=0 then goto abort;  { parser has fallen from stack; abort	}
      yystate := yyn;		  { simulate shift on error		}
      goto parse;
    end
  else				{ no shift yet; discard symbol 		}
    begin
      if yydebug then Ewriteln( Format( 'error recovery discards char %d',
				[yychar] ) );
      if yychar=0 then goto abort; { end of input; abort		}
      yychar := -1; goto next;	   { clear lookahead char and try again	}
    end;

shift:

  { go to new state, clear lookahead character:				}

  yystate := yyn; yychar := -1; yyval := yylval;
  if yyerrflag>0 then dec(yyerrflag);

  goto parse;

reduce:

  { execute action, pop rule from stack, and go to next state: 		}
  if yydebug then Ewriteln( Format('reduce %d', [-yyn] ) );

  yyflag := yyfnone; yyaction(-yyn);
  dec(yysp, yyr[-yyn].len);
  if yygoto(yys[yysp], yyr[-yyn].sym, yyn) then yystate := yyn;

  { handle action calls to yyaccept, yyabort and yyerror:		}

  case yyflag of
    yyfaccept : goto accept;
    yyfabort  : goto abort;
    yyferror  : goto errlab;
  end;

  goto parse;

accept:

  yyparse := 0; exit;

abort:

  yyparse := 1; exit;
end;	{ yyparse	}




{$I YaccExLex}

end.