unit TestForm;
{ Test noddy for yacc generated parser.				}
{ Author C.P.Osborne.							}
{ Modified:								}
{	26/09/2000	CPO	Created.				}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, LexFile;

type
  TfrmTest = class(TForm)
    SourceBox: TGroupBox;
    ResultBox: TGroupBox;
    ButtonBox: TGroupBox;
    GoButton: TBitBtn;
    LoadButton: TBitBtn;
    SourceMemo: TMemo;
    ResultMemo: TMemo;
    LoadDialog: TOpenDialog;
    ExitButton: TBitBtn;
    DebugButton: TBitBtn;
    ClearButton: TBitBtn;
    CheckButton: TBitBtn;
    procedure LoadButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ExitButtonClick(Sender: TObject);
    procedure GoButtonClick(Sender: TObject);
    procedure DebugButtonClick(Sender: TObject);
    procedure ClearButtonClick(Sender: TObject);
    procedure CheckButtonClick(Sender: TObject);
  private
    OPStr	: String;
    function OPHandler( mode : TFmode; C : Char ) : Char;
  end;

var
  frmTest: TfrmTest;

implementation

{$R *.DFM}
uses LexLib, YaccLib, Parser, ParseGlobals, DebugForm;

var
  Yacc	: TYacc;		{ Our parser.				}

{ Load a file into the source memo.					}
procedure TfrmTest.LoadButtonClick(Sender: TObject);
var
  T	: TextFile;
  S	: String;
begin
  with LoadDialog do
  begin
    InitialDir := ExtractFilePath(Application.ExeName);
    if Execute then
    begin
      AssignFile( T, FileName );
      Reset( T );
      SourceMemo.Lines.Clear;
      while not Eof( T ) do
      begin
	Readln( T, S );
	SourceMemo.Lines.Add(S);
      end;
      CloseFile( T );
    end;
  end;
end;	{ LoadButtonClick	}

{ Set up system on creation.						}
procedure TfrmTest.FormCreate(Sender: TObject);
begin
  { Create the parser...						}
  Yacc := TYacc.Create;

  { We only want #13 as end of line.					}
  LexEOL := #13;
end;	{ FormCreate	}

{ User has had enough - and who can blame him eh?			}
procedure TfrmTest.ExitButtonClick(Sender: TObject);
begin
  Close;
end;	{ ExitButtonClick	}

{ Do the interpreting thing.						}
procedure TfrmTest.GoButtonClick(Sender: TObject);
var
  I	: Integer;
begin
  { Clear result & variables.						}
  ResultMemo.Lines.Clear;
  frmDebug.DebugMemo.Lines.Clear;
  InitialiseVariables;

  { Reset lex stuff.							}
  Yacc.ylex.Reset;

  { Get input from source memo.						}
  Yacc.ylex.yyinput.AssignString(SourceMemo.Lines.Text);

  { Assign output to our handler.					}
  OPstr := '';
  Yacc.ylex.yyoutput.AssignMethod( OPHandler );

  { Assign debug message handler.					}
  Yacc.ylex.yyerrorfile.AssignMethod( frmDebug.OPHandler );
  Yacc.yydebug		:= True;
  Yacc.yydebuglex	:= True;

  { Finally parse the input.						}
  I := Yacc.yyparse;

  { Flush o/p string.							}
  if OPStr <> '' then
  begin
    ResultMemo.Lines.Add( OPStr );
    OPStr := '';
  end;
  frmDebug.Flush;

  if I <> 0 then
  begin
    case Parse_Error of
    0	: ShowMessage( 'Syntax error' );
    1	: ShowMessage( 'Division by zero' );
    2	: ShowMessage( 'Undefined variable' );
    5	: ShowMessage( 'Index out of range' );
    else  ShowMessage( 'Parse failed' );
    end;
  end;

end;	{ GoButtonClick	}

{ Output data handler.							}
function TfrmTest.OPHandler(mode: TFmode; C: Char): Char;
begin
  Result := #0;

  case mode of
    tfEOF : Result := #1;		{ Never end of file		}
    tfGet : raise ELFException.Create('Not an input file');
    tfPut : begin
	      if C in [#10,#13] then
	      begin
		ResultMemo.Lines.Add( OPStr );
		OPStr := '';
	      end else OPStr := OPStr + C;
	    end;
  end;
end;	{ OPHandler	}

{ Show or hide the debug form						}
procedure TfrmTest.DebugButtonClick(Sender: TObject);
begin
  if frmDebug.Visible then
  begin
    frmDebug.Hide;
  end else
  begin
    frmDebug.Show;
  end;
end;	{ DebugButtonClick	}

{ Clear the source pane.						}
procedure TfrmTest.ClearButtonClick(Sender: TObject);
begin
  SourceMemo.Lines.Clear;
end;	{ ClearButtonClick	}

{ Check syntax only.							}
procedure TfrmTest.CheckButtonClick(Sender: TObject);
var
  I	: Integer;
  S	: String;
begin
  { Clear result & variables.						}
  ResultMemo.Lines.Clear;
  frmDebug.DebugMemo.Lines.Clear;
  InitialiseVariables;

  { Prevent statement execution.					}
  Parse_If	:= False;
  Parse_Run	:= False;

  { Reset lex stuff.							}
  Yacc.ylex.Reset;

  { Get input from source memo.						}
  Yacc.ylex.yyinput.AssignString(SourceMemo.Lines.Text);

  { Assign output to our handler.					}
  OPstr := '';
  Yacc.ylex.yyoutput.AssignMethod( OPHandler );

  { Assign debug message handler.					}
  Yacc.ylex.yyerrorfile.AssignMethod( frmDebug.OPHandler );
  Yacc.yydebug		:= True;
  Yacc.yydebuglex	:= True;

  { Finally parse the input.						}
  I := Yacc.yyparse;

  { Flush o/p string.							}
  if OPStr <> '' then
  begin
    ResultMemo.Lines.Add( OPStr );
    OPStr := '';
  end;
  frmDebug.Flush;

  if I = 0 then ShowMessage('Parse Successful') else
  begin
    S := SourceMemo.Lines[Yacc.ylex.yylineno-1];
    SetLength( S, Yacc.ylex.yycolno - 1 );
    ShowMessage( Format('Syntax error on line %d, before column %d'#13'%s',
		 [Yacc.ylex.yylineno, Yacc.ylex.yycolno - 1, S]));
  end;
end;	{ CheckButtonClick	}

end.
