/* Yacc grammar for Test example
   Author C.P.Osborne.
   Modified:
	26/09/2000	CPO	Created.
*/
%{

uses YaccLib, LexLib, ParseGlobals;

%}

%token TASSIGN	 		/* :=				*/
%token RABS			/* absolute value		*/
%token BIF BENDIF		/* 'if' and 'endif'		*/
%token BIN			/* char in string		*/
%token <Real> NUMC      	/* real constants		*/
%token <String> STRC		/* String constants		*/
%token <Integer> RID		/* real variables		*/
%token <Integer> BID		/* boolean variables		*/
%token <Integer> SID		/* string variables		*/
%type <Real> expr		/* real expressions		*/
%type <Boolean> boolex		/* boolean expressions		*/
%type <String> sex		/* string expressions		*/

%nonassoc BTHEN
%nonassoc BELSE
%nonassoc '['
%left '<' '>' LE GE '=' NE	/* comparison operators		*/
%left '+' '-' BOR
%left '*' '/' BAND
%right UMINUS BNOT

%token ILLEGAL 			/* illegal token		*/

%%

input	: glist
	| input '#'		{ yyaccept; 		}
	;

ifpart	: BIF boolex BTHEN	{ Parse_If := $2 and Parse_Run;	}

elsepart: BELSE			{ Parse_If := Parse_Run and not Parse_If; }

endpart	: BENDIF		{ Parse_If := Parse_Run; }

glist	: gstmt
	| glist sep gstmt
	;

gstmt	: statemt | ifstmt
	;

ifstmt	: ifpart slist endpart
	| ifpart slist elsepart slist endpart
	;

slist	: statemt
	| slist sep statemt
	;

sep	: ';' | '\n'
	;

statemt	: /* empty = null statement	*/
	| RID TASSIGN expr 	{
				  if Parse_If then
				  begin
				    Parse_Reals[$1].RVal  := $3;
				    Parse_Reals[$1].State := tReal;
				  end;
				}
	| BID TASSIGN boolex	{
				  if Parse_If then
				  begin
				    Parse_Bools[$1].BVal := $3;
				    Parse_Bools[$1].State := tBoolean;
				  end;
				}
	| SID TASSIGN sex	{
				  if Parse_If then
				  begin
				    Parse_Strings[$1].SVal := $3;
				    Parse_Strings[$1].State := tString;
				  end;
				}
	| '?' expr 		{
				  if Parse_If then
				    ylex.yyoutput.Writeln(Format('%0.2f',[$2]));
				}
	| '?' boolex		{
				  if Parse_If then
				  begin
				    if $2 then ylex.yyoutput.Writeln('True')
				    else ylex.yyoutput.Writeln('False' );
				  end;
				}
	| '?' sex 		{
				  if Parse_If then ylex.yyoutput.Writeln($2);
				}
	;

/* Note that we only need to consider the 'if' state if the expressions
  are likely to cause trouble. For the others the check just takes
  as long as the calculation!
*/

expr    :  expr '+' expr	{ $$ := $1 + $3; 	}
	|  expr '-' expr	{ $$ := $1 - $3; 	}
	|  expr '*' expr	{ $$ := $1 * $3; 	}
	|  expr '/' expr	{
				  if Parse_If then
				  begin
					if $3 = 0 then
					begin
					  yyerror('Division by zero');
					  Parse_Error := 1;
					  yyabort;
					end
					else $$ := $1 / $3;
				  end;
				}
	|  RABS '(' expr ')'	{ $$ := abs( $3 );	}
	|  '(' expr ')'		{ $$ := $2; 		}
	|  '-' expr		{ $$ := -$2;		}
	   %prec UMINUS
	|  NUMC			{ $$ := $1; 		}
	|  RID			{
				  if Parse_If then
				  case Parse_Reals[$1].State of
				  tUndefined : begin
						yyerror('Undefined variable');
						Parse_Error := 2;
						yyabort;
					       end;
				  tReal : $$ := Parse_Reals[$1].RVal;
				  end;
				}
	;

boolex	: expr '<' expr		{ $$ := $1 < $3;	}
	| expr '>' expr		{ $$ := $1 > $3;	}
	| expr '=' expr		{ $$ := $1 = $3;	}
	| expr NE expr		{ $$ := $1 <> $3;	}
	| expr GE  expr		{ $$ := $1 >= $3;	}
	| expr LE  expr		{ $$ := $1 <= $3;	}
	| sex '=' sex		{ $$ := $1 = $3;	}
	| sex NE sex		{ $$ := $1 <> $3;	}
	| sex '<' sex		{ $$ := $1 < $3;	}
	| sex '>' sex		{ $$ := $1 > $3;	}
	| sex GE  sex		{ $$ := $1 >= $3;	}
	| sex LE  sex		{ $$ := $1 <= $3;	}
	| boolex '=' boolex	{ $$ := $1 = $3;	}
	| boolex NE boolex	{ $$ := $1 <> $3;	}
	| boolex BAND boolex	{ $$ := $1 and $3;	}
	| boolex BOR boolex	{ $$ := $1 or $3;	}
	| '(' boolex ')'	{ $$ := $2;		}
	| BNOT boolex		{ $$ := not $2;		}
	| sex BIN sex		{ $$ := pos($1,$3) <> 0;}
	| BID			{
				  if Parse_If then
				  case Parse_Bools[$1].State of
				  tUndefined : begin
						yyerror('Undefined variable');
						Parse_Error := 2;
						yyabort;
					       end;
				  tBoolean : $$ := Parse_Bools[$1].BVal;
				  end;
				}

	;

sex	: STRC			{ $$ := $1; 			}
	| sex '+' sex		{ $$ := $1 + $3;		}
	| sex '[' expr ']'	{
				  if (Integer(Trunc($3)) < 1) or
				    (Integer(Trunc($3)) > Length($1)) then
				  begin
				    yyerror('Index error');
				    Parse_Error := 5;
				    yyabort;
				  end else
				  begin
				    $$ := $1[Integer(Trunc($3))];
				  end;
				}
	| SID			{
				  if Parse_If then
				  case Parse_Strings[$1].State of
				  tUndefined : begin
						yyerror('Undefined variable');
						Parse_Error := 2;
						yyabort;
					       end;
				  tString : $$ := Parse_Strings[$1].SVal;
				  end;
				}
	;

%%

{$I YaccExLex}

end.
